searchData={"items":[{"type":"module","doc":"","title":"UkraineNbuqrEx","ref":"UkraineNbuqrEx.html"},{"type":"module","doc":"The UkraineNbuqrEx.Amount module handles parsing and formatting of monetary amounts\nfor Ukrainian hryvnia (UAH) in the context of NBU QR codes.\n\nThe module provides functionality to:\n- Parse string amounts into a structured format\n- Validate monetary amounts according to NBU specifications\n- Format amounts back to strings in the required NBU QR code format","title":"UkraineNbuqrEx.Amount","ref":"UkraineNbuqrEx.Amount.html"},{"type":"function","doc":"`normalize/1` format amount by parsing and converting amount back to string","title":"UkraineNbuqrEx.Amount.normalize/1","ref":"UkraineNbuqrEx.Amount.html#normalize/1"},{"type":"function","doc":"```elixir\n    iex> UkraineNbuqrEx.Amount.normalize(\"0123.40\")\n    \"UAH123.4\"\n\n    iex> UkraineNbuqrEx.Amount.normalize(\"123\")\n    \"UAH123\"\n```","title":"Examples - UkraineNbuqrEx.Amount.normalize/1","ref":"UkraineNbuqrEx.Amount.html#normalize/1-examples"},{"type":"function","doc":"`parse/1` cleans, splits, and validates the amount. It returns a struct with units and cents. If the amount is invalid, it returns an error tuple","title":"UkraineNbuqrEx.Amount.parse/1","ref":"UkraineNbuqrEx.Amount.html#parse/1"},{"type":"function","doc":"```elixir\n    iex> UkraineNbuqrEx.Amount.parse(\"123.45\")\n    {:ok, %UkraineNbuqrEx.Amount{units: \"123\", cents: \"45\"}}\n```","title":"Examples - UkraineNbuqrEx.Amount.parse/1","ref":"UkraineNbuqrEx.Amount.html#parse/1-examples"},{"type":"type","doc":"Amounts are represented as a struct with two fields:\n- `units`: The whole number part of the amount (hryvnias)\n- `cents`: The decimal part of the amount (kopiykas), optional","title":"UkraineNbuqrEx.Amount.t/0","ref":"UkraineNbuqrEx.Amount.html#t:t/0"},{"type":"function","doc":"`to_str/1` converts Amount struct to string representation in Ukrainian hryvnas formatted compatible with NBU QR code specification (with cents only if it exists and correct decimal separator)","title":"UkraineNbuqrEx.Amount.to_str/1","ref":"UkraineNbuqrEx.Amount.html#to_str/1"},{"type":"function","doc":"`validate/1` validates amount structure according to NBU requirements.\n\nValidation rules include:\n- Units must be a non-negative integer not exceeding 999,999,999\n- If cents are present, they must be between 0 and 99\n- Overall amount format must conform to NBU QR code specifications\n\nDelegate to `UkraineNbuqrEx.Amount.Validator.validate/1`","title":"UkraineNbuqrEx.Amount.validate/1","ref":"UkraineNbuqrEx.Amount.html#validate/1"},{"type":"function","doc":"- amount: A struct containing the parsed amount with units and optional cents","title":"Parameters - UkraineNbuqrEx.Amount.validate/1","ref":"UkraineNbuqrEx.Amount.html#validate/1-parameters"},{"type":"function","doc":"- `{:ok, amount}` if validation passes\n  - `{:error, message}` if validation fails","title":"Returns - UkraineNbuqrEx.Amount.validate/1","ref":"UkraineNbuqrEx.Amount.html#validate/1-returns"},{"type":"function","doc":"```elixir\n    iex> UkraineNbuqrEx.Amount.validate(%UkraineNbuqrEx.Amount{units: \"123\", cents: \"45\"})\n    {:ok, %UkraineNbuqrEx.Amount{units: \"123\", cents: \"45\"}}\n\n    iex> UkraineNbuqrEx.Amount.validate(%UkraineNbuqrEx.Amount{units: \"999999999\", cents: nil})\n    {:ok, %UkraineNbuqrEx.Amount{units: \"999999999\", cents: nil}}\n\n    iex> UkraineNbuqrEx.Amount.validate(%UkraineNbuqrEx.Amount{units: \"1000000000\", cents: nil})\n    {:error, \"Amount greather then 999999999.99\"}\n```","title":"Examples - UkraineNbuqrEx.Amount.validate/1","ref":"UkraineNbuqrEx.Amount.html#validate/1-examples"},{"type":"module","doc":"Amount.Validator validates amount structs\nCorrect amount must be less than 999_999_999.99 and greater than 0","title":"UkraineNbuqrEx.Amount.Validator","ref":"UkraineNbuqrEx.Amount.Validator.html"},{"type":"function","doc":"validate/1 validates amount struct","title":"UkraineNbuqrEx.Amount.Validator.validate/1","ref":"UkraineNbuqrEx.Amount.Validator.html#validate/1"},{"type":"function","doc":"```elixir\n    iex> UkraineNbuqrEx.Amount.Validator.validate(%UkraineNbuqrEx.Amount{units: \"100\", cents: \"5\"})\n    {:ok, %UkraineNbuqrEx.Amount{units: \"100\", cents: \"5\"}}\n\n    iex> UkraineNbuqrEx.Amount.Validator.validate(%UkraineNbuqrEx.Amount{units: \"999999999\", cents: \"99\"})\n    {:ok, %UkraineNbuqrEx.Amount{units: \"999999999\", cents: \"99\"}}\n\n    iex> UkraineNbuqrEx.Amount.Validator.validate(%UkraineNbuqrEx.Amount{units: \"0\", cents: \"01\"})\n    {:ok, %UkraineNbuqrEx.Amount{units: \"0\", cents: \"01\"}}\n\n    iex> UkraineNbuqrEx.Amount.Validator.validate(%UkraineNbuqrEx.Amount{units: \"1000000000\", cents: nil})\n    {:error, \"Amount greather then 999999999.99\"}\n\n    iex> UkraineNbuqrEx.Amount.Validator.validate(%UkraineNbuqrEx.Amount{units: \"1000000000\", cents: \"1\"})\n    {:error, \"Amount greather then 999999999.99\"}\n\n    iex> UkraineNbuqrEx.Amount.Validator.validate(%UkraineNbuqrEx.Amount{units: \"0\", cents: nil})\n    {:error, \"Zero amount\"}\n```","title":"Examples - UkraineNbuqrEx.Amount.Validator.validate/1","ref":"UkraineNbuqrEx.Amount.Validator.html#validate/1-examples"},{"type":"module","doc":"","title":"UkraineNbuqrEx.Commons","ref":"UkraineNbuqrEx.Commons.html"},{"type":"function","doc":"","title":"UkraineNbuqrEx.Commons.negative/1","ref":"UkraineNbuqrEx.Commons.html#negative/1"},{"type":"function","doc":"","title":"UkraineNbuqrEx.Commons.ok/1","ref":"UkraineNbuqrEx.Commons.html#ok/1"},{"type":"function","doc":"","title":"UkraineNbuqrEx.Commons.positive/2","ref":"UkraineNbuqrEx.Commons.html#positive/2"},{"type":"module","doc":"This module is designed to generate Payment QR codes according to the National Bank of Ukraine (NBU) QR code standard.","title":"UkraineNbuqrEx.Qr","ref":"UkraineNbuqrEx.Qr.html"},{"type":"function","doc":"Generates a QR code from the given data and options.\nAs opttions it accepts the same options as to_qr/2 and to_string/2 functions.","title":"UkraineNbuqrEx.Qr.create/2","ref":"UkraineNbuqrEx.Qr.html#create/2"},{"type":"function","doc":"`encode/1` encodes the invoice string to Base64 format uses URL-safe Base64 encoding without padding","title":"UkraineNbuqrEx.Qr.encode/1","ref":"UkraineNbuqrEx.Qr.html#encode/1"},{"type":"type","doc":"","title":"UkraineNbuqrEx.Qr.input_data/0","ref":"UkraineNbuqrEx.Qr.html#t:input_data/0"},{"type":"type","doc":"","title":"UkraineNbuqrEx.Qr.output_data/0","ref":"UkraineNbuqrEx.Qr.html#t:output_data/0"},{"type":"function","doc":"Generates a complete QR link with encoded invoice data","title":"UkraineNbuqrEx.Qr.to_link/1","ref":"UkraineNbuqrEx.Qr.html#to_link/1"},{"type":"function","doc":"`to_qr/2` generates a QR from the given data and options.\n\n**format** option specifies the function for formatiing QR code.\nThe default is &Config.svg/2. Complete list of format functions returns by Config.formats:\n  - **&Config.svg/2** generates an SVG image\n  - **&Config.png/2** generates a PNG image\n  - **&Config.ascii/2** generates a text representation of the QR code\n\nAvailable options for all formats:\n  - **color** in hexadecimal format. The default is #000\n  - **background_color** in hexadecimal format or :transparent. The default is #FFF.\n  - **width** the width of the QR code in pixel. Without the width attribute, the QR code size will be dynamically generated based on the input string.\n\nOptions avaliable for SVG format:\n  - **shape** only square or circle. The default is square\n  - **viewbox** when set to true, the SVG element will specify its height and width using viewBox, instead of explicit height and width tags.\n\nDefault options are\n```elixir\n  [color: \"#000\", shape: \"square\", background_color: \"#FFF\"]\n```","title":"UkraineNbuqrEx.Qr.to_qr/2","ref":"UkraineNbuqrEx.Qr.html#to_qr/2"},{"type":"function","doc":"`to_string/2`  converts QR data struct to string representation of open data of invoice\nCombines QR data struct (service label, version, encoding, function, recipient, IBAN, amount, tax ID, purpose) into a string representation  with newline separators.\n\nTakes optional formatting options:\n  - **encoding** specifies encoding (defaults to value from Config.encoding())\n  - **version** specifies version (defaults to value from Config.version())","title":"UkraineNbuqrEx.Qr.to_string/2","ref":"UkraineNbuqrEx.Qr.html#to_string/2"},{"type":"module","doc":"Configuration constants for QR code generation","title":"UkraineNbuqrEx.Qr.Config","ref":"UkraineNbuqrEx.Qr.Config.html"},{"type":"function","doc":"","title":"UkraineNbuqrEx.Qr.Config.ascii/2","ref":"UkraineNbuqrEx.Qr.Config.html#ascii/2"},{"type":"function","doc":"base_url/0 returns base URL for QR Code generation","title":"UkraineNbuqrEx.Qr.Config.base_url/0","ref":"UkraineNbuqrEx.Qr.Config.html#base_url/0"},{"type":"function","doc":"","title":"UkraineNbuqrEx.Qr.Config.default_format/2","ref":"UkraineNbuqrEx.Qr.Config.html#default_format/2"},{"type":"function","doc":"encoding/0 returns default encoding for QR Code is 1 (UTF-8) (delegetes to Encoding module)","title":"UkraineNbuqrEx.Qr.Config.encoding/0","ref":"UkraineNbuqrEx.Qr.Config.html#encoding/0"},{"type":"function","doc":"","title":"UkraineNbuqrEx.Qr.Config.formats/0","ref":"UkraineNbuqrEx.Qr.Config.html#formats/0"},{"type":"function","doc":"function/0 returns default function of QR Code is ”UCT“ (Ukrainian Credit Transfer)","title":"UkraineNbuqrEx.Qr.Config.function/0","ref":"UkraineNbuqrEx.Qr.Config.html#function/0"},{"type":"function","doc":"","title":"UkraineNbuqrEx.Qr.Config.png/2","ref":"UkraineNbuqrEx.Qr.Config.html#png/2"},{"type":"function","doc":"service_label/0 returns default service label for QR Code is ”BCD“","title":"UkraineNbuqrEx.Qr.Config.service_label/0","ref":"UkraineNbuqrEx.Qr.Config.html#service_label/0"},{"type":"function","doc":"default_format/0 returns function that generetes QR Code in default format SVG (delegetes to EQRCode module)","title":"UkraineNbuqrEx.Qr.Config.svg/2","ref":"UkraineNbuqrEx.Qr.Config.html#svg/2"},{"type":"function","doc":"version/0 returns default version for QR Code is 1 (delegetes to Version module)","title":"UkraineNbuqrEx.Qr.Config.version/0","ref":"UkraineNbuqrEx.Qr.Config.html#version/0"},{"type":"module","doc":"","title":"UkraineNbuqrEx.Qr.Encoding","ref":"UkraineNbuqrEx.Qr.Encoding.html"},{"type":"function","doc":"","title":"UkraineNbuqrEx.Qr.Encoding.default/0","ref":"UkraineNbuqrEx.Qr.Encoding.html#default/0"},{"type":"function","doc":"label/1 returns encoding by label or {:error, “Unknown encoding”} if label is unknown encoding numbers also may be used as labels","title":"UkraineNbuqrEx.Qr.Encoding.encoding/1","ref":"UkraineNbuqrEx.Qr.Encoding.html#encoding/1"},{"type":"function","doc":"","title":"UkraineNbuqrEx.Qr.Encoding.encodings/0","ref":"UkraineNbuqrEx.Qr.Encoding.html#encodings/0"},{"type":"function","doc":"","title":"UkraineNbuqrEx.Qr.Encoding.label/1","ref":"UkraineNbuqrEx.Qr.Encoding.html#label/1"},{"type":"type","doc":"QR Data Encoding\n1 - UTF-8 (default)\n2 - WIN 1251","title":"UkraineNbuqrEx.Qr.Encoding.t/0","ref":"UkraineNbuqrEx.Qr.Encoding.html#t:t/0"},{"type":"module","doc":"","title":"UkraineNbuqrEx.Qr.Version","ref":"UkraineNbuqrEx.Qr.Version.html"},{"type":"function","doc":"","title":"UkraineNbuqrEx.Qr.Version.default/0","ref":"UkraineNbuqrEx.Qr.Version.html#default/0"},{"type":"function","doc":"","title":"UkraineNbuqrEx.Qr.Version.normalize/1","ref":"UkraineNbuqrEx.Qr.Version.html#normalize/1"},{"type":"function","doc":"","title":"UkraineNbuqrEx.Qr.Version.normalize!/1","ref":"UkraineNbuqrEx.Qr.Version.html#normalize!/1"},{"type":"type","doc":"QR Data Version. By default use the 1 version.","title":"UkraineNbuqrEx.Qr.Version.t/0","ref":"UkraineNbuqrEx.Qr.Version.html#t:t/0"},{"type":"module","doc":"Defines a struct representing the open data part of National Bank of Ukraine (NBU) payment Quick Response (QR) Code.","title":"UkraineNbuqrEx.QrData","ref":"UkraineNbuqrEx.QrData.html"},{"type":"module","doc":"* `:recipient` - The name of the payment recipient\n  * `:iban` - International Bank Account Number\n  * `:amount` - Payment amount\n  * `:tax_id` - Tax identification number\n  * `:purpose` - Purpose of payment/transaction","title":"Struct Fields - UkraineNbuqrEx.QrData","ref":"UkraineNbuqrEx.QrData.html#module-struct-fields"},{"type":"module","doc":"```elixir\n    %UkraineNbuqrEx.QrData{\n      recipient: \"Company Name Ltd\",\n      iban: \"UA213223130000026007233566001\",\n      amount: \"1000.00\",\n      tax_id: \"12345678\",\n      purpose: \"Payment for services\"\n    }\n```\n\nAll fields are required when creating a new QrData struct.","title":"Example - UkraineNbuqrEx.QrData","ref":"UkraineNbuqrEx.QrData.html#module-example"},{"type":"type","doc":"NBU QR Data structure containing payment information","title":"UkraineNbuqrEx.QrData.t/0","ref":"UkraineNbuqrEx.QrData.html#t:t/0"},{"type":"module","doc":"A module for building National Bank of Ukraine (NBU) payment Quick Response (QR) code data structures.","title":"UkraineNbuqrEx.QrData.Builder","ref":"UkraineNbuqrEx.QrData.Builder.html"},{"type":"function","doc":"Builds a QR data struct from the given parameters.\n\nThis builder validates and formats payment information according to NBU QR code specifications.\nIt enforces required fields and length restrictions for various payment details.","title":"UkraineNbuqrEx.QrData.Builder.build/1","ref":"UkraineNbuqrEx.QrData.Builder.html#build/1"},{"type":"function","doc":"The following maximum length restrictions are enforced:\n- recipient: 70 characters\n- amount: 15 characters\n- tax_id: 10 characters\n- iban: 34 characters\n- purpose: 140 characters","title":"Length Restrictions - UkraineNbuqrEx.QrData.Builder.build/1","ref":"UkraineNbuqrEx.QrData.Builder.html#build/1-length-restrictions"},{"type":"function","doc":"```elixir\n    iex> params = [\n    ...>   iban: \"UA213223130000026007233566001\",\n    ...>   tax_id: \"12345678\",\n    ...>   amount: \"123.45\",\n    ...>   recipient: \"Company Name\",\n    ...>   purpose: \"Payment for services\"\n    ...> ]\n    ...> UkraineNbuqrEx.QrData.Builder.build(params)\n\n    {:ok, %UkraineNbuqrEx.QrData{recipient: \"Company Name\", iban: \"UA213223130000026007233566001\", amount: \"UAH123.45\", tax_id: \"12345678\", purpose: \"Payment for services\"}} = UkraineNbuqrEx.QrData.Builder.build(params)\n```","title":"Usage - UkraineNbuqrEx.QrData.Builder.build/1","ref":"UkraineNbuqrEx.QrData.Builder.html#build/1-usage"},{"type":"function","doc":"All of the following parameters are required:\n- `:iban` - Ukrainian IBAN (must start with \"UA\")\n- `:tax_id` - Valid Ukrainian tax identification number\n- `:amount` - Payment amount (will be normalized)\n- `:recipient` - Name of the payment recipient\n- `:purpose` - Purpose of payment\n\nThe builder will return an error if any required parameter is missing or invalid.","title":"Required Parameters - UkraineNbuqrEx.QrData.Builder.build/1","ref":"UkraineNbuqrEx.QrData.Builder.html#build/1-required-parameters"},{"type":"function","doc":"- IBAN is validated to ensure it's a valid Ukrainian IBAN\n- Tax ID is validated using the UkraineTaxidEx library\n- Amount is validated and normalized to ensure proper format\n- All text fields are truncated to their maximum allowed lengths","title":"Validation - UkraineNbuqrEx.QrData.Builder.build/1","ref":"UkraineNbuqrEx.QrData.Builder.html#build/1-validation"},{"type":"extras","doc":"# UkraineNbuqrEx","title":"UkraineNbuqrEx","ref":"readme.html"},{"type":"extras","doc":"**As described in Payment QR Code Specification from NBU (National Bank of Ukraine)**\n\nQR Code establishes unified rules for QR code formation and usage for credit transfers in Ukraine and aims to improve payment convenience. Usage of Payment QR Codes is unified but not mandatory for payment participants","title":"Key facts about Payment QR Codes - UkraineNbuqrEx","ref":"readme.html#key-facts-about-payment-qr-codes"},{"type":"extras","doc":"- Uses UTF-8 or Win1251 encoding for Cyrillic characters\n- ISO 646 for non-Cyrillic characters\n- Error correction levels: M (15%) or L (7%)\n- Maximum QR code version: 15 (77 modules) for format 002","title":"Key Technical Parameters - UkraineNbuqrEx","ref":"readme.html#key-technical-parameters"},{"type":"extras","doc":"- Service mark (\"BCD\")\n- Format version\n- Encoding type\n- Function code (\"UCT\" - Ukrainian Credit Transfer)\n- Recipient information\n- Account number\n- Recipient code (EDRPOU/passport/tax number)\n- Payment purpose","title":"Mandatory Data Elements - UkraineNbuqrEx","ref":"readme.html#mandatory-data-elements"},{"type":"extras","doc":"- Amount/currency (UAH only)\n- Display text\n- Reference number\n- Some reserved fields for future use","title":"Optional Elements - UkraineNbuqrEx","ref":"readme.html#optional-elements"},{"type":"extras","doc":"- Each field is separated by line endings (LF or CR+LF)\n- Minimum recommended module size is 0.5mm for proper scanning\n- QR codes can be printed on invoices or displayed electronically\n- Can be scanned using device cameras, payment apps, or specialized banking equipment","title":"Implementation Details - UkraineNbuqrEx","ref":"readme.html#implementation-details"},{"type":"extras","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `ukraine_nbuqr` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ukraine_nbuqr, \"~> 0.1.0\"}\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","title":"Installation - UkraineNbuqrEx","ref":"readme.html#installation"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}